@@ -1,6 +1,6 @@
 package Perl::LanguageServer;
 
-use v5.18;
+use v5.16;
 
 use strict ;
 use Moose ;
@@ -15,7 +15,7 @@ use JSON ;
 use Data::Dump qw{dump} ;
 use IO::Select ;
 
-use Perl::LanguageServer::Req ; 
+use Perl::LanguageServer::Req ;
 use Perl::LanguageServer::Workspace ;
 
 with 'Perl::LanguageServer::Methods' ;
@@ -29,11 +29,11 @@ Perl::LanguageServer - Language Server and Debug Protocol Adapter for Perl
 
 =head1 VERSION
 
-Version 2.4.0
+Version 2.5.0
 
 =cut
 
-our $VERSION = '2.4.0';
+our $VERSION = '2.5.0';
 
 
 =head1 SYNOPSIS
@@ -78,7 +78,7 @@ has 'channel' =>
     (
     is => 'ro',
     isa => 'Coro::Channel',
-    default => sub { Coro::Channel -> new }    
+    default => sub { Coro::Channel -> new }
     ) ;
 
 has 'debug' =>
@@ -133,28 +133,28 @@ sub logger
         $src = shift ;
         }
     $src = $self if (!$src) ;
-    
+
     if ($log_file)
         {
         open my $fh, '>>', $log_file or warn "$log_file : $!" ;
-        print $fh $src?$src -> log_prefix . ': ':'', @_ ;    
+        print $fh $src?$src -> log_prefix . ': ':'', @_ ;
         close $fh ;
         }
     else
         {
-        print STDERR $src?$src -> log_prefix . ': ':'', @_ ;    
+        print STDERR $src?$src -> log_prefix . ': ':'', @_ ;
         }
     }
 
 
 # ---------------------------------------------------------------------------
 
-sub send_notification 
+sub send_notification
     {
     my ($self, $notification, $src, $txt) = @_ ;
 
     $txt ||= "<--- Notification: " ;
-    $notification -> {jsonrpc} = '2.0' ;       
+    $notification -> {jsonrpc} = '2.0' ;
     my $outdata = $json -> encode ($notification) ;
     my $guard = $self -> out_semaphore -> guard  ;
     use bytes ;
@@ -170,7 +170,7 @@ sub send_notification
 
 # ---------------------------------------------------------------------------
 
-sub call_method 
+sub call_method
     {
     my ($self, $reqdata, $req, $id) = @_ ;
 
@@ -181,7 +181,7 @@ sub call_method
     if ($method =~ /^(\w+)\/(\w+)$/)
         {
         $module = $1 ;
-        $name   = $2 ;    
+        $name   = $2 ;
         }
     elsif ($method =~ /^(\w+)$/)
         {
@@ -189,13 +189,13 @@ sub call_method
         }
     elsif ($method =~ /^\$\/(\w+)$/)
         {
-        $name   = $1 ;    
+        $name   = $1 ;
         }
     else
         {
-        die "Unknown method $method" ;    
+        die "Unknown method $method" ;
         }
-    $module = $req -> type eq 'dbgint'?'DebugAdapterInterface':'DebugAdapter' if ($req -> is_dap) ;    
+    $module = $req -> type eq 'dbgint'?'DebugAdapterInterface':'DebugAdapter' if ($req -> is_dap) ;
 
     my $base_package = __PACKAGE__ . '::Methods' ;
     my $package = $base_package ;
@@ -217,7 +217,7 @@ sub call_method
         $perlmethod = '_dapreq_' . $name ;
         }
     else
-        {    
+        {
         $perlmethod = (defined($id)?'_rpcreq_':'_rpcnot_') . $name ;
         }
     $self -> logger ("method=$perlmethod\n") if ($debug1) ;
@@ -225,7 +225,7 @@ sub call_method
 
 no strict ;
     return $self -> $perlmethod ($workspace, $req) ;
-use strict ;    
+use strict ;
     }
 
 # ---------------------------------------------------------------------------
@@ -238,8 +238,8 @@ sub process_req
     $xid ||= $reqseq++ ;
     $running_coros{$xid} = async
         {
-        my $req_guard = Guard::guard 
-            { 
+        my $req_guard = Guard::guard
+            {
             $self -> logger ("done handle_req id=$xid\n") if ($debug1) ;
             delete $running_reqs{$xid} ;
             delete $running_coros{$xid} ;
@@ -254,7 +254,7 @@ sub process_req
 
         my $rsp ;
         my $outdata ;
-        my $outjson ; 
+        my $outjson ;
         eval
             {
             $rsp = $self -> call_method ($reqdata, $req, $id) ;
@@ -264,10 +264,10 @@ sub process_req
                 $outjson = { request_seq => -$id, seq => -$id, command => $reqdata -> {command}, success => JSON::true, type => 'response', $rsp?(body => $rsp):()}  ;
                 }
             else
-                {    
+                {
                 $outjson = { id => $id, jsonrpc => '2.0', result => $rsp}  if ($rsp) ;
                 }
-            $outdata = $json -> encode ($outjson) if ($outjson) ; 
+            $outdata = $json -> encode ($outjson) if ($outjson) ;
             } ;
         if ($@)
             {
@@ -277,10 +277,10 @@ sub process_req
                 $outjson = { request_seq => -$id, command => $reqdata -> {command}, success => JSON::false, message => "$@", , type => 'response'} ;
                 }
             else
-                {    
+                {
                 $outjson = { id => $id, jsonrpc => '2.0', error => { code => -32001, message => "$@" }} ;
                 }
-            $outdata = $json -> encode ($outjson) if ($outjson) ; 
+            $outdata = $json -> encode ($outjson) if ($outjson) ;
             }
 
         if (defined($id))
@@ -298,7 +298,7 @@ sub process_req
                 $sum += $cnt ;
                 }
 
-            if ($debug1) 
+            if ($debug1)
                 {
                 $wrdata =~ s/\r//g ;
                 $self -> logger ("<--- Response: ", $jsonpretty -> encode ($outjson), "\n") ;
@@ -332,10 +332,10 @@ sub mainloop
                 die "read_error reading headers ($!)" if ($cnt < 0) ;
                 return if ($cnt == 0) ;
                 }
-                
+
             while ($buffer =~ s/^(.*?)\R//)
                 {
-                $line = $1 ;    
+                $line = $1 ;
                 $self -> logger ("line=<$line>\n") if ($debug2) ;
                 last header if ($line eq '') ;
                 $header{$1} = $2 if ($line =~ /(.+?):\s*(.+)/) ;
@@ -347,7 +347,7 @@ sub mainloop
         return 1 if ($len == 0);
         my $data ;
         #$self -> logger ("len=$len len buffer=", length ($buffer), "\n")  if ($debug2) ;
-        while ($len > length ($buffer)) 
+        while ($len > length ($buffer))
             {
             $cnt = $self -> _read (\$buffer, $len - length ($buffer), length ($buffer)) ;
 
@@ -355,12 +355,12 @@ sub mainloop
             die "read_error reading data ($!)" if ($cnt < 0) ;
             return if ($cnt == 0) ;
             }
-        if ($len == length ($buffer)) 
+        if ($len == length ($buffer))
             {
             $data = $buffer ;
             $buffer = '' ;
             }
-        elsif ($len < length ($buffer)) 
+        elsif ($len < length ($buffer))
             {
             $data = substr ($buffer, 0, $len) ;
             $buffer = substr ($buffer, $len) ;
@@ -368,13 +368,13 @@ sub mainloop
         else
             {
             die "to few data bytes" ;
-            }    
+            }
         $self -> logger ("read data=", $data, "\n")  if ($debug2) ;
         $self -> logger ("read header=", dump (\%header), "\n")  if ($debug2) ;
 
         my $reqdata ;
         $reqdata = $json -> decode ($data) if ($data) ;
-        if ($debug1) 
+        if ($debug1)
             {
             $self -> logger ($self -> log_req_txt, $jsonpretty -> encode ($reqdata), "\n") ;
             }
@@ -382,7 +382,7 @@ sub mainloop
 
         $self -> process_req ($id, $reqdata)  ;
         cede () ;
-        } 
+        }
 
     return 1 ;
     }
@@ -450,8 +450,8 @@ sub _run_tcp_server
                         {
                         my ($fh) = @_ ;
                         syswrite ($fh, "Content-Length: 0\r\n\r\n") if ($fh) ;
-                        } ;        
-                    }    
+                        } ;
+                    }
                 $@ = undef ;
                 Coro::AnyEvent::sleep (2) ;
                 IO::AIO::reinit () ; # stop AIO requests
@@ -473,12 +473,12 @@ sub run
         {
         if ($opt eq '--debug')
             {
-            $debug1 = $debug2 = 1  ;    
+            $debug1 = $debug2 = 1  ;
             }
         elsif ($opt eq '--log-level')
             {
             $debug1 = shift @ARGV  ;
-            $debug2 = $debug1 > 1?1:0 ;    
+            $debug2 = $debug1 > 1?1:0 ;
             }
         elsif ($opt eq '--log-file')
             {
@@ -486,44 +486,45 @@ sub run
             }
         elsif ($opt eq '--port')
             {
-            $listen_port = shift @ARGV  ;    
+            $listen_port = shift @ARGV  ;
             }
         elsif ($opt eq '--nostdio')
             {
-            $no_stdio = 1  ;    
+            $no_stdio = 1  ;
             }
         elsif ($opt eq '--heartbeat')
             {
-            $heartbeat = 1  ;    
+            $heartbeat = 1  ;
             }
         elsif ($opt eq '--version')
             {
-            $client_version = shift @ARGV  ;    
+            $client_version = shift @ARGV  ;
             }
         }
 
     $|= 1 ;
-    
+
     my $cv = AnyEvent::CondVar -> new ;
 
-   if ($heartbeat || $debug2)
+    async
         {
-        async
+        my $i = 0 ;
+        while (1)
             {
-            my $i = 0 ;
-            while (1)
+            if ($heartbeat || $debug2)
                 {
                 logger (undef, "##### $i #####\n running: " . dump (\%running_reqs) . " coros: " . dump (\%running_coros), "\n") ;
-                Coro::AnyEvent::sleep (10) ;
                 $i++ ;
                 }
-            } ;
-        }
-   
+
+            Coro::AnyEvent::sleep (10) ;
+            }
+        } ;
+
     if (!$no_stdio)
         {
         async
-            {    
+            {
             my $self = Perl::LanguageServer -> new ({out_fh => 1, in_fh => 0});
 
             $self -> mainloop () ;
@@ -538,18 +539,18 @@ sub run
         } ;
 
     $cv -> recv ;
-    $exit = 1 ;    
+    $exit = 1 ;
     }
 
 # ---------------------------------------------------------------------------
 
 sub parsews
     {
-    my $class = shift ;    
+    my $class = shift ;
     my @args = @_ ;
 
     $|= 1 ;
-    
+
     my $cv = AnyEvent::CondVar -> new ;
 
     async
@@ -559,7 +560,7 @@ sub parsews
         my %folders ;
         foreach my $path (@args)
             {
-            $folders{$path} = $path ;      
+            $folders{$path} = $path ;
             }
         $workspace -> folders (\%folders) ;
         $workspace -> background_parser ($self) ;
@@ -567,18 +568,18 @@ sub parsews
         $cv -> send ;
         } ;
 
-    $cv -> recv ;    
+    $cv -> recv ;
     }
 
 # ---------------------------------------------------------------------------
 
 sub check_file
     {
-    my $class = shift ;    
+    my $class = shift ;
     my @args = @_ ;
 
     $|= 1 ;
-    
+
     my $cv = AnyEvent::CondVar -> new ;
 
     my $self = Perl::LanguageServer -> new ;
@@ -588,7 +589,7 @@ sub check_file
         my %folders ;
         foreach my $path (@args)
             {
-            $folders{$path} = $path ;      
+            $folders{$path} = $path ;
             }
         $workspace -> folders (\%folders) ;
         $workspace -> background_checker ($self) ;
@@ -603,12 +604,12 @@ sub check_file
             my $text ;
             aio_load ($path, $text) ;
 
-            $workspace -> check_perl_syntax ($workspace, $path, $text) ;      
+            $workspace -> check_perl_syntax ($workspace, $path, $text) ;
             }
-        
+
         } ;
 
-    $cv -> recv ;    
+    $cv -> recv ;
     }
 
 1 ;
@@ -659,7 +660,7 @@ Language Server and Debug Protocol Adapter for Perl
 
 =item * Support for coro threads
 
-=item * Breakpoints 
+=item * Breakpoints
 
 =item * Conditional breakpoints
 
@@ -683,7 +684,7 @@ Language Server and Debug Protocol Adapter for Perl
 
 =item * Run inside docker container
 
-=item * Run inside kubernetes 
+=item * Run inside kubernetes
 
 =back
 
@@ -714,8 +715,19 @@ e.g. on Debian/Ubuntu run:
      sudo cpan Perl::LanguageServer
     
 
+e.g. on Centos 7 run:
+
+
+    
+      sudo yum install perl-App-cpanminus perl-AnyEvent-AIO perl-Coro
+      sudo cpanm Class::Refresh
+      sudo cpanm Compiler::Lexer
+      sudo cpanm Hash::SafeKeys
+      sudo cpanm Perl::LanguageServer
+    
+
 In case any of the above packages are not available for your os version, just
-leave then out. The cpan command will install missing dependencies. In case
+leave them out. The cpan command will install missing dependencies. In case
 the test fails, when running cpan C<install>, you should try to run C<force install>.
 
 =head2 Extension Settings
@@ -788,7 +800,7 @@ This extension contributes the following settings:
 
 =item * C<args>:   optional, array with arguments for perl program
 
-=item * C<env>:    optional, object with environment settings 
+=item * C<env>:    optional, object with environment settings
 
 =item * C<cwd>:    optional, change working directory before launching the debuggee
 
@@ -815,7 +827,7 @@ Example: if your local path is \10.11.12.13\share\path\to\ws and on the remote m
 
     "sshWorkspaceRoot": "/path/to/ws"
 
-The other possibility is to provide a pathMap. This allows to have multiple mappings.
+The other possibility is to provide a pathMap. This allows to having multiple mappings.
 
 Examples:
 
@@ -853,15 +865,15 @@ There are more container options, see above.
 
 =head3 Working directory is not defined
 
-It is not defined what the current working directory is at the start of a perl program. 
-So Perl::LanguageServer makes no assumtion about it. To solve the problem you can set 
-the directory via cwd configurationm parameter in launch.json for debugging.
+It is not defined what the current working directory is at the start of a perl program.
+So Perl::LanguageServer makes no assumptions about it. To solve the problem you can set
+the directory via cwd configuration parameter in launch.json for debugging.
 
 =head3 Module not found when debugging or during syntax check
 
-If you reference a module with a relative path or if you assume that the current working directory 
+If you reference a module with a relative path or if you assume that the current working directory
 is part of the Perl search path, it will not work.
-Instead set the perl include path to a fixed absolue path. In your settings.json do something like:
+Instead set the perl include path to a fixed absolute path. In your settings.json do something like:
 
 
         "perl.perlInc": [
@@ -874,7 +886,7 @@ C<perl.perlInc> should be an absolute path.
 
 =head3 AnyEvent, Coro Warning during install
 
-You need to install the AnyEvent::IO and Coro. Just ignore the warning that it might not work. For Perl::LanguageServer it works fine. 
+You need to install the AnyEvent::IO and Coro. Just ignore the warning that it might not work. For Perl::LanguageServer it works fine.
 
 =head3 'richterger.perl' failed: options.port should be >= 0 and < 65536
 
@@ -887,17 +899,17 @@ or make sure you are running in the expected directory by setting the C<cwd> set
 
 =head3 ERROR: Unknow perlmethod I<rpcnot>setTraceNotification
 
-This is not an issue, that just means that not all features of the debugging protocol are implemented. 
+This is not an issue, that just means that not all features of the debugging protocol are implemented.
 Also it says ERROR, it's just a warning and you can safely ignore it.
 
-=head3 The debugger sometime stop a random places
+=head3 The debugger sometimes stops at random places
 
 Upgrade to Version 2.4.0
 
 =head3 Message about Perl::LanguageServer has crashed 5 times
 
-This is an problem when more then one instance of Perl::LanguageServer is running.
-Upgrade to Version 2.4.0 solve this problem.
+This is a problem when more than one instance of Perl::LanguageServer is running.
+Upgrade to Version 2.4.0 solves this problem.
 
 =head3 Carton support
 
@@ -920,10 +932,10 @@ If you are using LL<https://metacpan.org/pod/Carton> to manage dependencies, add
 =head2 Known Issues
 
 Does not yet work on windows, due to issues with reading from stdin.
-I wasn't able to find a reliable way to do a non blocking read from stdin on windows. 
+I wasn't able to find a reliable way to do a non-blocking read from stdin on windows.
 I would be happy, if anyone knows how to do this in Perl.
 
-Anyway Perl::LanguageServer runs without problems inside of Windows Subsystem for Linux (WSL).
+Anyway, Perl::LanguageServer runs without problems inside of Windows Subsystem for Linux (WSL).
 
 =head2 Release Notes
 
@@ -959,7 +971,7 @@ example Visual Studio Code or Atom.
 
 https://microsoft.github.io/language-server-protocol/specification
 
-It also implements the Debug Adapter Protocol, which allow debugging
+It also implements the Debug Adapter Protocol, which allows debugging
 with various editors/includes
 
 https://microsoft.github.io/debug-adapter-protocol/overview
@@ -975,7 +987,7 @@ Any comments and patches are welcome.
 Copyright 2018-2022 Gerald Richter.
 
 This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
+under the terms of the Artistic License (2.0). You may obtain a
 copy of the full license at:
 
 LL<http://www.perlfoundation.org/artistic_license_2_0>
@@ -1012,22 +1024,45 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 Change Log
 
-=head2 2.4.0   C<18.11.2022>
+=head2 2.5.0   C<2023-02-05>
+
+=over
+
+=item * Set minimal Perl version to 5.16 (#91)
+
+=item * Per default enviroment from vscode will be passed to debuggee, syntax check and perltidy.
+
+=item * Add configuration C<disablePassEnv> to not pass enviroment variables.
+
+=item * Support for C<logLevel> and C<logFile> settings via LanguageServer protocol and
+not only via command line options (#97) [schellj]
+
+=item * Fix: "No DB::DB routine defined" (#91) [peterdragon]
+
+=item * Fix: Typos and spelling in README (#159) [dseynhae]
+
+=item * Fix: Update call to gensym(), to fix 'strict subs' error (#164) [KohaAloha]
+
+=item * Convert identention from tabs to spaces and remove trailing whitespaces 
+
+=back
+
+=head2 2.4.0   C<2022-11-18>
 
 =over
 
 =item * Choose a different port for debugAdapterPort if it is already in use. This
-avoids trouble with starting Perl::LanguageServer if another instance
-of Perl::LanguageServer is runing on the same machine (thanks to hakonhagland)
+avoids trouble with starting C<Perl::LanguageServer> if another instance
+of C<Perl::LanguageServer> is runing on the same machine (thanks to hakonhagland)
 
-=item * Add configuration debugAdapterPortRange, for choosing range of port for dynamic
+=item * Add configuration C<debugAdapterPortRange>, for choosing range of port for dynamic
 port assignment
 
-=item * Add support for using LanguageServer and debugger inside a Container. 
+=item * Add support for using LanguageServer and debugger inside a Container.
 Currently docker containers und containers running inside kubernetes are supported.
 
-=item * When starting debugger session and stopOnEntry is false, do not switch to sourefile
-where debugger would stop, when stopOnEntry is true.
+=item * When starting debugger session and C<stopOnEntry> is false, do not switch to sourefile
+where debugger would stop, when C<stopOnEntry> is true.
 
 =item * Added some FAQs in README
 
@@ -1035,35 +1070,35 @@ where debugger would stop, when stopOnEntry is true.
 
 =item * Fix: debugAdapterPort is now numeric
 
-=item * Fix: debugging loop with each statement (#107) 
+=item * Fix: debugging loop with each statement (#107)
 
 =item * Fix: display of arrays in variables pane on mac (#120)
 
-=item * Fix: encoding for perltidy (#127)
+=item * Fix: encoding for C<perltidy> (#127)
 
-=item * Fix: return error if perltidy fails, so text is not removed by failing 
+=item * Fix: return error if C<perltidy> fails, so text is not removed by failing
 formatting request (#87)
 
 =item * Fix: FindBin does not work when checking syntax (#16)
 
 =back
 
-=head2 2.3.0   C<26.09.2021>
+=head2 2.3.0   C<2021-09-26>
 
 =over
 
-=item * Arguments section in Variable lists now @ARGV and @_ during debugging (#105)
+=item * Arguments section in Variable lists now C<@ARGV> and C<@_> during debugging (#105)
 
-=item * @_ is now correctly evaluated inside of debugger console
+=item * C<@_> is now correctly evaluated inside of debugger console
 
-=item * $#foo is now correctly evaluated inside of debugger console
+=item * C<$#foo> is now correctly evaluated inside of debugger console
 
 =item * Default debug configuration is now automatically provided without
-the need to create a launch.json first (#103)
+the need to create a C<launch.json> first (#103)
 
-=item * Add Option cacheDir to specify location of cache dir (#113)
+=item * Add Option C<cacheDir> to specify location of cache dir (#113)
 
-=item * Fix: Debugger outputted invalid thread reference causes "no such coroutine" message, 
+=item * Fix: Debugger outputted invalid thread reference causes "no such coroutine" message,
 so watchs and code from the debug console is not expanded properly
 
 =item * Fix: LanguageServer hangs when multiple request send at once from VSCode to LanguageServer
@@ -1074,7 +1109,7 @@ so watchs and code from the debug console is not expanded properly
 
 =item * Fix: sshArgs parameter was not declared as array (#109)
 
-=item * Disable syntax check on windows, because it blocks the whole process when running on windows, 
+=item * Disable syntax check on windows, because it blocks the whole process when running on windows,
 until handling of childs processes is fixed
 
 =item * Fixed spelling (#86,#96,#101) [chrstphrchvz,davorg,aluaces]
@@ -1085,7 +1120,7 @@ until handling of childs processes is fixed
 
 =over
 
-=item * Parser now supports Moose method modifieres before, after and around, 
+=item * Parser now supports Moose method modifieres before, after and around,
 so they can be used in symbol view and within reference search
 
 =item * Support Format Document and Format Selection via perltidy
@@ -1142,7 +1177,7 @@ running threads which in turn caused the LanguageServer to hang
 
 =item * Add Presentation on Perl Workshop 2020 to repos
 
-=item * Remove Compiler::Lexer from distribution since 
+=item * Remove Compiler::Lexer from distribution since
 version is available on CPAN
 
 =item * Make stdout unbuffered while debugging
@@ -1163,9 +1198,13 @@ version is available on CPAN
 
 =head2 2.0.2    C<2020-01-22>
 
-Plugin: Fix command line parameters for plink
+=over
 
-Perl::LanguageServer: Fix handling of multiple parallel request, improve symlink handling, add support for UNC paths in path mapping, improve logging for logLevel = 1
+=item * Plugin: Fix command line parameters for plink
+
+=item * Perl::LanguageServer: Fix handling of multiple parallel request, improve symlink handling, add support for UNC paths in path mapping, improve logging for logLevel = 1
+
+=back
 
 =head2 2.0.1    C<2020-01-14>
 
